<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';
import SelectMatView from '@/components/mat/selectMat/index.vue'

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const selectMatChild = ref(null)
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;

    if(isSave.value) {
        formData.value.matIdList = formData.value.matId;
    }
    console.log(formData.value);

    post(isSave.value ? '/api/suggestLocRule/save' : '/api/suggestLocRule/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const matQueryList = ref(null);
matQuery();
function matQuery() {
    postForm('/api/mat/query', {}).then(resp => {
        let result = resp.data;
        matQueryList.value = result.data;
    })
}
const userQueryList = ref(null);
userQuery();
function userQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        userQueryList.value = result.data;
    })
}

const handleSelectMatClick = () => {
    selectMatChild.value.open = true;
}

const handleSelectMatOk = (result) => {
    let tmp = [];

    if(formData.value.matId != undefined) {
        tmp = [...formData.value.matId]
    }

    result.forEach((id) => {
        if(tmp.indexOf(id) == -1) {
            tmp.push(id);
        }
    })

    formData.value.matId = tmp;
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '推荐区域-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }"
                :wrapper-col="{ span: 16 }" style="display: flex;justify-content: space-between;flex-wrap: wrap;"
                autocomplete="off" @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.locType$', '库位类型')" name="locType$"
                    style="width: 250px;">
                    <a-select v-model:value="formData.locType" :options="[
                        { label: '满托', value: 1 },
                        { label: '空托', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item v-if="formData.locType != 0" :label="formatMessage('db.strategy_suggest_loc_rule.mat_id', '商品')" name="matId"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-select v-model:value="formData.matId" mode="multiple" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="matQueryList" optionFilterProp="label"
                        optionLabelProp="label" @click="handleSelectMatClick" :open="false">
                    </a-select>
                </a-form-item>
                <a-form-item v-if="formData.locType != 0" :label="formatMessage('db.strategy_suggest_loc_rule.batch', '批号')" name="batch"
                    style="width: 250px;">
                    <a-input v-model:value="formData.batch" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.start_row', '起始排')" name="startRow"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startRow" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.target_row', '结束排')" name="targetRow"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetRow" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.start_bay', '起始列')" name="startBay"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startBay" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.target_bay', '结束列')" name="targetBay"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetBay" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.start_lev', '起始层')" name="startLev"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.startLev" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.target_lev', '结束层')" name="targetLev"
                    style="width: 250px;" :rules="[{ required: true }]">
                    <a-input v-model:value="formData.targetLev" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.status', '状态')" name="status"
                    style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <!-- <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.create_time', '添加时间')"
                    name="createTime" style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.update_time', '修改时间')"
                    name="updateTime" style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="userQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.strategy_suggest_loc_rule.memo', '备注')" name="memo"
                    style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>

        <SelectMatView ref="selectMatChild" @handle-ok="handleSelectMatOk" />
    </div>
</template>

<style></style>
